package com.ruoyi.system.service.impl;

import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.function.Function;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TdTrainMapper;
import com.ruoyi.system.domain.TdTrain;
import com.ruoyi.system.service.ITdTrainService;
import com.ruoyi.common.core.text.Convert;

/**
 * 涉密人员培训Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-04-11
 */
@Service
public class TdTrainServiceImpl extends ServiceImpl<TdTrainMapper,TdTrain> implements ITdTrainService
{
    @Autowired
    private TdTrainMapper tdTrainMapper;

    /**
     * 查询涉密人员培训
     * 
     * @param ID 涉密人员培训主键
     * @return 涉密人员培训
     */
    @Override
    public TdTrain selectTdTrainByID(Long ID)
    {
        return tdTrainMapper.selectTdTrainByID(ID);
    }

    /**
     * 查询涉密人员培训列表
     * 
     * @param tdTrain 涉密人员培训
     * @return 涉密人员培训
     */
    @Override
    public List<TdTrain> selectTdTrainList(TdTrain tdTrain)
    {
        return tdTrainMapper.selectTdTrainList(tdTrain);
    }

    /**
     * 新增涉密人员培训
     * 
     * @param tdTrain 涉密人员培训
     * @return 结果
     */
    @Override
    public int insertTdTrain(TdTrain tdTrain)
    {
        return tdTrainMapper.insertTdTrain(tdTrain);
    }

    /**
     * 修改涉密人员培训
     * 
     * @param tdTrain 涉密人员培训
     * @return 结果
     */
    @Override
    public int updateTdTrain(TdTrain tdTrain)
    {
        return tdTrainMapper.updateTdTrain(tdTrain);
    }

    /**
     * 批量删除涉密人员培训
     * 
     * @param IDs 需要删除的涉密人员培训主键
     * @return 结果
     */
    @Override
    public int deleteTdTrainByIDs(String IDs)
    {
        return tdTrainMapper.deleteTdTrainByIDs(Convert.toStrArray(IDs));
    }

    /**
     * 删除涉密人员培训信息
     * 
     * @param ID 涉密人员培训主键
     * @return 结果
     */
    @Override
    public int deleteTdTrainByID(Long ID)
    {
        return tdTrainMapper.deleteTdTrainByID(ID);
    }


    @Override
    public boolean saveBatch(Collection<TdTrain> entityList, int batchSize) {
        return false;
    }

    @Override
    public boolean saveOrUpdateBatch(Collection<TdTrain> entityList, int batchSize) {
        return false;
    }

    @Override
    public boolean updateBatchById(Collection<TdTrain> entityList, int batchSize) {
        return false;
    }

    @Override
    public boolean saveOrUpdate(TdTrain entity) {
        return false;
    }

    @Override
    public TdTrain getOne(Wrapper<TdTrain> queryWrapper, boolean throwEx) {
        return null;
    }

    @Override
    public Map<String, Object> getMap(Wrapper<TdTrain> queryWrapper) {
        return null;
    }

    @Override
    public <V> V getObj(Wrapper<TdTrain> queryWrapper, Function<? super Object, V> mapper) {
        return null;
    }

    @Override
    public Class<TdTrain> getEntityClass() {
        return null;
    }
}
